#
# spec file for package python-openstack-doc-tools
#
# Copyright (c) 2022 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%global module os_doc_tools
Name:           python-openstack-doc-tools
Version:        3.3.1
Release:        1.6
Summary:        OpenStack Docs Tools
License:        Apache-2.0
Group:          Development/Languages/Python
URL:            https://docs.openstack.org/openstack-doc-tools
Source0:        https://files.pythonhosted.org/packages/source/o/openstack-doc-tools/openstack-doc-tools-3.3.1.tar.gz
BuildRequires:  openstack-macros
BuildRequires:  python3-PyYAML >= 3.13
BuildRequires:  python3-Sphinx
BuildRequires:  python3-lxml >= 4.5.0
BuildRequires:  python3-openstackdocstheme
BuildRequires:  python3-pbr >= 2.0.0
BuildArch:      noarch

%description
Tools used by the OpenStack Documentation Project.

%package -n python3-openstack-doc-tools
Summary:        OpenStack Docs Tools
Requires:       python3-PyYAML >= 3.13
Requires:       python3-Sphinx
Requires:       python3-iso8601 >= 0.1.11
Requires:       python3-lxml >= 4.5.0
Requires:       python3-openstackdocstheme
%if 0%{?suse_version}
Obsoletes:      python2-openstack-doc-tools < 1.8.0
%endif

%description -n python3-openstack-doc-tools
Tools used by the OpenStack Documentation Project.

This package contains the Python 3.x module.

%prep
%autosetup -n openstack-doc-tools-%{version}
%py_req_cleanup

%build
%py3_build

%install
%py3_install

%files -n python3-openstack-doc-tools
%license LICENSE
%doc README.rst
%{_bindir}/doc-tools-build-rst
%{_bindir}/doc-tools-check-languages
%{python3_sitelib}/%{module}
%{_datadir}/openstack-doc-tools
%{python3_sitelib}/*.egg-info

%changelog
* Tue Jun  7 2022 cloud-devel@suse.de
- update to version 3.3.1
  - Use TOX_CONSTRAINTS_FILE
  - Use py3 as the default runtime for tox
  - Use Python 3.8 as the default runtime for tox
  - Update CI to use unversioned jobs template
  - Dropping lower constraints testing
  - Move flake8 as a pre-commit local target.
  - Adding pre-commit
* Tue May 24 2022 Dirk Müller <dmueller@suse.com>
- remove unneded dependencies
* Tue Feb  1 2022 Steve Kowalik <steven.kowalik@suse.com>
- demjson is no longer required, remove it from BuildRequires.
* Sun May  2 2021 Dirk Müller <dmueller@suse.com>
- update to wallaby template (url fixup)
* Fri Oct  9 2020 cloud-devel@suse.de
- update to version 3.3.0
  - switch documentation job to new PTI
  - Switch to newer openstackdocstheme and reno versions
  - Check RST as part of linting
  - fix tox python3 overrides
  - OpenDev Migration Patch
  - Replace git.openstack.org URLs with opendev.org URLs
  - Update sitemap for Python3
  - Remove openstack-jsoncheck and openstack-indexpage
  - Remove setup.py check from pep8 job
  - setup.cfg: Cleanup and update some urls to latest
  - Cleanup py27 support
  - import zuul job settings from project-config
  - Advancing the protocal of the website to HTTPS in README.rst.
  - Drop py35 testing
  - tox: Keeping going with docs
  - Add python-requires >= 3.6
  - Publish to publish-docs/html
  - Cleanup doc-tools-check-languages
  - Remove support for py34
  - Use unittest.mock instead of mock
  - Change openstack-dev to openstack-discuss
  - Update docs building
  - Update the constraints url
  - Don't use special api-quick-start location
  - Drop python 2.7 support and testing
  - [goal] Migrate testing to ubuntu focal
  - Update sitemap file
  - Add Python 3 Train unit tests
  - Switch to stestr
  - add python 3.6 unit test job
  - Use openstack-lower-constraints-jobs template
  - Remove demjson from requirements
  - Remove some commented obsolete lines
  - Update hacking
  - Update sitemap
  - Switch to ussuri python3 jobs
  - Update hacking for Python3
  - Update home-page
* Tue Jul 14 2020 Dirk Mueller <dmueller@suse.com>
- add obsoletes to make factory review team happy
* Tue May 12 2020 Dirk Mueller <dmueller@suse.com>
- switch to stable/ussuri template (drops python 2.x support)
* Fri Dec 20 2019 Dirk Mueller <dmueller@suse.com>
- switch to stable/train template
* Tue Sep  4 2018 cloud-devel@suse.de
- update to version 1.8.0
  - Update hacking
  - Remove cliff-tablib dependency
  - Do not add EOL releases to sitemap
  - Add openssl libs to bindep
  - Include 'deprecation' as a flag
  - sitemap: Add ocata
  - Fix to use "." to source script files
  - Remove pylint
  - Cleanup doc-tools-check-languages
  - Remove 'autogenerate_config_docs'
  - Update RELEASE_NOTES
  - extract_swift_flags: Remove 'docbook' command
  - Avoid tox_install.sh for constraints support
  - Update docs theme configuration
  - [autohelp] Update opt types
  - Remove swift tooling
  - Update sitemap tests
  - trivial: Remove 'pass_through'
  - Change priorities for sitemap
  - Remove setting of version/release from releasenotes
  - [diff_branches] remove the broken --format option
  - Index options by group too
  - Actually skip 'update' when flagmapping are disabled
  - add lower-constraints job
  - Add bindep.txt
  - Remove some useless files
  - Remove "cleanup" tools
  - option.help can be None
  - Clean imports in code
  - Remove MANIFEST.in file
  - Add missing doc for dump in autohelp-wrapper
  - Remove unused oslo.config requirement
  - Update links in README
  - Remove the 'openstack-auto-commands' tool
  - [cli-ref] add API version for cinder explicitly
  - Switch to openstackdocstheme
  - [cli-ref] add line break to avoid lengthy line
  - [autohelp] Return options as dicts instead of lists
  - Fix URLs
  - Add release-note about docs
  - Make openstack-doc-tools can be used in the individual client repos
  - Remove handling of install-guide/config-reference for Pike
  - Simplify the format of paragraphs
  - Allow overriding of openstack-manuals dir
  - [lang] Fixes PUBLISH_DIR for api-quick-start
  - Handle object type when registering runtime options in autohelp
  - Separate option formatting
  - Remove unnecessary parameter
  - Update index page
  - Document installation of scrapy via pip
  - Update ZUUL variables for Zuul v3
  - Updated from global requirements
  - extract_swift_flags: Remove '--from' argument
  - Make flagmapping optional
* Fri Feb 23 2018 tbechtold@suse.com
- Switch to stable/queens spec template
* Mon Aug  7 2017 cloud-devel@suse.de
- update to version 1.5.0
  - Add py35 to trove classifier
  - Typo fix: occured => occurred
  - [cli-ref] emphasize the warning
  - [cli-ref] support vitrage command
  - [cli-ref] Remove Block Storage API V1 note
  - Remove support for py33
  - [cli-ref] support aodhclient
  - [cli-ref] fix insufficient markups
  - Update to point to launchpad openstack-doc-tools
  - Fix building of translated Install Guides on Mitaka
  - [cli-ref] support required arguments option
  - Updated from global requirements
  - [cli-ref] add gnocchi subcommands
  - Remove :option:
  - [cli-ref] Remove Image API V1
* Fri Feb 10 2017 cloud-devel@suse.de
- update to version 1.3.0:
  - Properly pass arguments for language building
  - Link to Contributor Guide instead of wiki
  - [config-ref] Remove heading and trailing blanks from help
  - Fix TypeError in autohelp.py
  - Remove Babel requirement
  - Enable release notes translation
  - [config-ref] update service names for diff branches
  - [config-ref] support URIOpt/HostnameOpt to auto config doc tool
  - Remove docbook
  - [config-ref] support IPOpt into auto config doc tool
  - Make hooks module import optional
  - Increase hacking version
  - [config-ref] Update README for RHEL/CentOS; diff_branches for Ocata
  - [cli-ref] unlink the openstack command
  - [cli-ref] support Backup, Restore, and DR service
  - Change assertTrue(isinstance()) by optimal assert
  - Add pdf file link in build result page
  - Fix doc-tools-check-languages
  - Show team and repo badges on README
  - Don't include openstack/common in flake8 exclude list
  - Typo mistake
  - Improve the README file of the sitemap generator
  - Remove unnecessary white space
  - Move release notes to be handled by reno
  - doc-tools-check-languages: Output NEWREV
  - [cli-ref] support NFV Orchestration service
  - Changing 'raise e' to 'raise' to prevent exception masking
  - Move SitemapItem class into generator.spiders.sitemap_file
  - Skip docutils version that errors on remote images
  - [config-ref] fix pattern matching for bullet list
  - Update flake8 ignore list
  - Only build debconf if it exists
  - PDF support using --pdf option
  - Add error check for doc-tools-check-languages
  - [cli-ref] remove deprecated Block Storage API v1
  - Gen autogenerate_config_docs/README.rst
  - [cli-ref] cleanup osc cli reference tools
  - [config-ref] remove unnecessary template files
  - Add root-marker file to translated manuals
  - Add prefix "$" for command examples
  - [cli-ref] add project name with service name
  - Add Constraints support
  - [cli-reference] remove unnecessary subcommand list for freezer
  - [cli-reference] remove sahara CLI support
  - H803 have been deprecated
  - [cli-ref] unsupport the openstack command
  - Updated from global requirements
  - Mitaka is an old release now
* Tue Oct 11 2016 dmueller@suse.com
- Initial package (1.0.1)
